@@ -4,7 +4,7 @@ from WebKit import *
 
 class TestWebBackForwardList (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(WebBackForwardList.containsItem_)
+        self.assertResultIsBOOL(WebBackForwardList.containsItem_)
 
 if __name__ == "__main__":
     main()
